@@ -1,12 +1,20 @@
 """
 kbatch
 """
-from ._core import list_jobs, submit_job, configure, show_job, logs
+from ._core import (
+    list_jobs,
+    submit_job,
+    configure,
+    show_job,
+    logs,
+    list_pods,
+    logs_streaming,
+)
 from ._types import Job
 from ._backend import make_job
 
 
-__version__ = "0.2.14"
+__version__ = "0.3.2"
 
 __all__ = [
     "__version__",
