@@ -19,12 +19,14 @@ def cli():
 @click.option("--kbatch-url")
 @click.option("--token")
 def configure(kbatch_url, token):
+    """Write a configuration file to use for future kbatch actions."""
     p = _core.configure(kbatch_url, token)
     rich.print(f"[green]Wrote config to[/green] [bold]{str(p)}[/bold]")
 
 
 @cli.group()
 def job():
+    """Manage kbatch jobs."""
     pass
 
 
@@ -33,6 +35,7 @@ def job():
 @click.option("--token", help="File to execute.")
 @click.argument("job_name")
 def show(job_name, kbatch_url, token):
+    """Show the details for a job."""
     result = _core.show_job(job_name, kbatch_url, token)
     rich.print_json(data=result)
 
@@ -40,6 +43,16 @@ def show(job_name, kbatch_url, token):
 @job.command()
 @click.option("--kbatch-url", help="URL to the kbatch server.")
 @click.option("--token", help="File to execute.")
+@click.argument("job_name")
+def delete(job_name, kbatch_url, token):
+    """Delete a job, cancelling running pods."""
+    result = _core.delete_job(job_name, kbatch_url, token)
+    rich.print_json(data=result)
+
+
+@job.command(name="list")
+@click.option("--kbatch-url", help="URL to the kbatch server.")
+@click.option("--token", help="File to execute.")
 @click.option(
     "-o",
     "--output",
@@ -47,7 +60,8 @@ def show(job_name, kbatch_url, token):
     type=click.Choice(["json", "table"]),
     default="json",
 )
-def list(kbatch_url, token, output):
+def list_jobs(kbatch_url, token, output):
+    """List all the jobs."""
     result = _core.list_jobs(kbatch_url, token)
 
     if output == "json":
@@ -72,8 +86,26 @@ def list(kbatch_url, token, output):
 @click.option("-f", "--file", help="Configuration file.")
 @click.option("--kbatch-url", help="URL to the kbatch server.")
 @click.option("--token", help="JupyterHub API token.")
+@click.option(
+    "-o",
+    "--output",
+    default="json",
+    help="Output format.",
+    type=click.Choice(["json", "name"]),
+)
 def submit(
-    file, code, name, description, image, command, args, profile, kbatch_url, token, env
+    file,
+    code,
+    name,
+    description,
+    image,
+    command,
+    args,
+    profile,
+    kbatch_url,
+    token,
+    env,
+    output,
 ):
     """
     Submit a job to run on Kubernetes.
@@ -118,26 +150,14 @@ def submit(
         token=token,
         profile=profile,
     )
-    rich.print_json(data=result)
-
-
-@job.command()
-@click.argument("job_name")
-@click.option("--kbatch-url", help="URL to the kbatch server.")
-@click.option("--token", help="File to execute.")
-@click.option("--pretty/--no-pretty", default=True)
-def logs(job_name, kbatch_url, token, pretty):
-    result = _core.logs(job_name, kbatch_url, token)
-    if pretty:
-        import rich
-
-        rich.print(result)
-    else:
-        print(result)
+    if output == "json":
+        rich.print_json(data=result)
+    elif output == "name":
+        print(result["metadata"]["name"])
 
 
 @cli.command()
-@click.option("--kbatch-url")
+@click.option("--kbatch-url", help="URL to the kbatch server.")
 def profiles(kbatch_url):
     """
     Show the profiles used by the server.
@@ -147,3 +167,64 @@ def profiles(kbatch_url):
     """
     p = _core.show_profiles(kbatch_url)
     rich.print_json(data=p)
+
+
+@cli.group()
+def pod():
+    """Manage job pods."""
+    pass
+
+
+@pod.command(name="list")
+@click.option("--kbatch-url", help="URL to the kbatch server.")
+@click.option("--token", help="File to execute.")
+@click.option(
+    "--job-name", help="The name of the job to limit the results to.", default=None
+)
+@click.option(
+    "-o",
+    "--output",
+    help="output format",
+    type=click.Choice(["json", "table", "name"]),
+    default="json",
+)
+def list_pods(kbatch_url, token, job_name, output):
+    """List all the pods."""
+    result = _core.list_pods(kbatch_url, token, job_name)
+
+    if output == "json":
+        rich.print_json(data=result)
+    elif output == "table":
+        rich.print(_core.format_pods(result))
+    elif output == "name":
+        names = [x["metadata"]["name"] for x in result["items"]]
+        rich.print("\n".join(names))
+
+
+# TODO show pod
+
+
+@pod.command()
+@click.argument("pod_name")
+@click.option("--kbatch-url", help="URL to the kbatch server.")
+@click.option("--token", help="File to execute.")
+@click.option("--stream/--no-stream", help="Whether to stream the logs", default=False)
+@click.option("--read-timeout", help="Timeout for reading data", default=60, type=int)
+@click.option("--pretty/--no-pretty", default=True)
+def logs(pod_name, kbatch_url, token, stream, pretty, read_timeout):
+    """Get the logs for a kbatch pod."""
+    if pretty:
+        print = rich.print
+
+    if stream:
+        result = _core.logs_streaming(
+            pod_name, kbatch_url, token, read_timeout=read_timeout
+        )
+    else:
+        result = _core.logs(pod_name, kbatch_url, token, read_timeout=read_timeout)
+
+    if stream:
+        for line in result:
+            print(line)
+    else:
+        print(result)
